# Adaptivity

The Adaptivity commands are used to define objects, perform analyses, and calculate new meshes for Arbitrary Lagrangian Eularian (ALE) adaptive smoothing (adaptive meshing) and varying topology adaptivity (adaptive remeshing).

## Create adaptivity mesh control features

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.AdaptivityModel.AdaptivityModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Create adaptivity mesh state features

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.AdaptivityStep.AdaptivityStep
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Create features for AdaptivityIteration

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.AdaptivityIteration.AdaptivityIteration
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### AdaptiveMeshConstraint

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.AdaptiveMeshConstraint.AdaptiveMeshConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AdaptiveMeshConstraintState

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.AdaptiveMeshConstraintState.AdaptiveMeshConstraintState
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

### AdaptiveMeshControl

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.AdaptiveMeshControl.AdaptiveMeshControl
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AdaptiveMeshDomain

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.AdaptiveMeshDomain.AdaptiveMeshDomain
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AdaptivityProcess

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.AdaptivityProcess.AdaptivityProcess
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DisplacementAdaptiveMeshConstraint

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.DisplacementAdaptiveMeshConstraint.DisplacementAdaptiveMeshConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DisplacementAdaptiveMeshConstraintState

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.DisplacementAdaptiveMeshConstraintState.DisplacementAdaptiveMeshConstraintState
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ErrorIndicatorResult

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.ErrorIndicatorResult.ErrorIndicatorResult
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RemeshingRule

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.RemeshingRule.RemeshingRule
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RuleResult

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.RuleResult.RuleResult
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### VelocityAdaptiveMeshConstraint

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.VelocityAdaptiveMeshConstraint.VelocityAdaptiveMeshConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### VelocityAdaptiveMeshConstraintState

```{eval-rst}
.. autoclass:: abaqus.Adaptivity.VelocityAdaptiveMeshConstraintState.VelocityAdaptiveMeshConstraintState
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
